# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from tekton.models.v1beta1_task_resource_binding import V1beta1TaskResourceBinding  # noqa: F401,E501


class V1beta1TaskRunResources(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'inputs': 'list[V1beta1TaskResourceBinding]',
        'outputs': 'list[V1beta1TaskResourceBinding]'
    }

    attribute_map = {
        'inputs': 'inputs',
        'outputs': 'outputs'
    }

    def __init__(self, inputs=None, outputs=None):  # noqa: E501
        """V1beta1TaskRunResources - a model defined in Swagger"""  # noqa: E501

        self._inputs = None
        self._outputs = None
        self.discriminator = None

        if inputs is not None:
            self.inputs = inputs
        if outputs is not None:
            self.outputs = outputs

    @property
    def inputs(self):
        """Gets the inputs of this V1beta1TaskRunResources.  # noqa: E501

        Inputs holds the inputs resources this task was invoked with  # noqa: E501

        :return: The inputs of this V1beta1TaskRunResources.  # noqa: E501
        :rtype: list[V1beta1TaskResourceBinding]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this V1beta1TaskRunResources.

        Inputs holds the inputs resources this task was invoked with  # noqa: E501

        :param inputs: The inputs of this V1beta1TaskRunResources.  # noqa: E501
        :type: list[V1beta1TaskResourceBinding]
        """

        self._inputs = inputs

    @property
    def outputs(self):
        """Gets the outputs of this V1beta1TaskRunResources.  # noqa: E501

        Outputs holds the inputs resources this task was invoked with  # noqa: E501

        :return: The outputs of this V1beta1TaskRunResources.  # noqa: E501
        :rtype: list[V1beta1TaskResourceBinding]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        """Sets the outputs of this V1beta1TaskRunResources.

        Outputs holds the inputs resources this task was invoked with  # noqa: E501

        :param outputs: The outputs of this V1beta1TaskRunResources.  # noqa: E501
        :type: list[V1beta1TaskResourceBinding]
        """

        self._outputs = outputs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1TaskRunResources, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TaskRunResources):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client import V1ContainerState  # noqa: F401,E501
from tekton.models.v1_time import V1Time  # noqa: F401,E501


class V1beta1ConditionCheckStatusFields(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'check': 'V1ContainerState',
        'completion_time': 'V1Time',
        'pod_name': 'str',
        'start_time': 'V1Time'
    }

    attribute_map = {
        'check': 'check',
        'completion_time': 'completionTime',
        'pod_name': 'podName',
        'start_time': 'startTime'
    }

    def __init__(self, check=None, completion_time=None, pod_name=None, start_time=None):  # noqa: E501
        """V1beta1ConditionCheckStatusFields - a model defined in Swagger"""  # noqa: E501

        self._check = None
        self._completion_time = None
        self._pod_name = None
        self._start_time = None
        self.discriminator = None

        if check is not None:
            self.check = check
        if completion_time is not None:
            self.completion_time = completion_time
        self.pod_name = pod_name
        if start_time is not None:
            self.start_time = start_time

    @property
    def check(self):
        """Gets the check of this V1beta1ConditionCheckStatusFields.  # noqa: E501

        Check describes the state of the check container.  # noqa: E501

        :return: The check of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :rtype: V1ContainerState
        """
        return self._check

    @check.setter
    def check(self, check):
        """Sets the check of this V1beta1ConditionCheckStatusFields.

        Check describes the state of the check container.  # noqa: E501

        :param check: The check of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :type: V1ContainerState
        """

        self._check = check

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1ConditionCheckStatusFields.  # noqa: E501

        CompletionTime is the time the check pod completed.  # noqa: E501

        :return: The completion_time of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1ConditionCheckStatusFields.

        CompletionTime is the time the check pod completed.  # noqa: E501

        :param completion_time: The completion_time of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def pod_name(self):
        """Gets the pod_name of this V1beta1ConditionCheckStatusFields.  # noqa: E501

        PodName is the name of the pod responsible for executing this condition check.  # noqa: E501

        :return: The pod_name of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :rtype: str
        """
        return self._pod_name

    @pod_name.setter
    def pod_name(self, pod_name):
        """Sets the pod_name of this V1beta1ConditionCheckStatusFields.

        PodName is the name of the pod responsible for executing this condition check.  # noqa: E501

        :param pod_name: The pod_name of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :type: str
        """
        if pod_name is None:
            raise ValueError("Invalid value for `pod_name`, must not be `None`")  # noqa: E501

        self._pod_name = pod_name

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1ConditionCheckStatusFields.  # noqa: E501

        StartTime is the time the check is actually started.  # noqa: E501

        :return: The start_time of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1ConditionCheckStatusFields.

        StartTime is the time the check is actually started.  # noqa: E501

        :param start_time: The start_time of this V1beta1ConditionCheckStatusFields.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1ConditionCheckStatusFields, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1ConditionCheckStatusFields):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from tekton.models.knative_condition import KnativeCondition  # noqa: F401,E501
from tekton.models.v1_time import V1Time  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_run_result import V1beta1PipelineRunResult  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_run_task_run_status import V1beta1PipelineRunTaskRunStatus  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_spec import V1beta1PipelineSpec  # noqa: F401,E501


class V1beta1PipelineRunStatus(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'annotations': 'dict(str, str)',
        'completion_time': 'V1Time',
        'conditions': 'list[KnativeCondition]',
        'observed_generation': 'int',
        'pipeline_results': 'list[V1beta1PipelineRunResult]',
        'pipeline_spec': 'V1beta1PipelineSpec',
        'start_time': 'V1Time',
        'task_runs': 'dict(str, V1beta1PipelineRunTaskRunStatus)'
    }

    attribute_map = {
        'annotations': 'annotations',
        'completion_time': 'completionTime',
        'conditions': 'conditions',
        'observed_generation': 'observedGeneration',
        'pipeline_results': 'pipelineResults',
        'pipeline_spec': 'pipelineSpec',
        'start_time': 'startTime',
        'task_runs': 'taskRuns'
    }

    def __init__(self, annotations=None, completion_time=None, conditions=None, observed_generation=None, pipeline_results=None, pipeline_spec=None, start_time=None, task_runs=None):  # noqa: E501
        """V1beta1PipelineRunStatus - a model defined in Swagger"""  # noqa: E501

        self._annotations = None
        self._completion_time = None
        self._conditions = None
        self._observed_generation = None
        self._pipeline_results = None
        self._pipeline_spec = None
        self._start_time = None
        self._task_runs = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if completion_time is not None:
            self.completion_time = completion_time
        if conditions is not None:
            self.conditions = conditions
        if observed_generation is not None:
            self.observed_generation = observed_generation
        if pipeline_results is not None:
            self.pipeline_results = pipeline_results
        if pipeline_spec is not None:
            self.pipeline_spec = pipeline_spec
        if start_time is not None:
            self.start_time = start_time
        if task_runs is not None:
            self.task_runs = task_runs

    @property
    def annotations(self):
        """Gets the annotations of this V1beta1PipelineRunStatus.  # noqa: E501

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :return: The annotations of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this V1beta1PipelineRunStatus.

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :param annotations: The annotations of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1PipelineRunStatus.  # noqa: E501

        CompletionTime is the time the PipelineRun completed.  # noqa: E501

        :return: The completion_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1PipelineRunStatus.

        CompletionTime is the time the PipelineRun completed.  # noqa: E501

        :param completion_time: The completion_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1PipelineRunStatus.  # noqa: E501

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :return: The conditions of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: list[KnativeCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1PipelineRunStatus.

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :param conditions: The conditions of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: list[KnativeCondition]
        """

        self._conditions = conditions

    @property
    def observed_generation(self):
        """Gets the observed_generation of this V1beta1PipelineRunStatus.  # noqa: E501

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :return: The observed_generation of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: int
        """
        return self._observed_generation

    @observed_generation.setter
    def observed_generation(self, observed_generation):
        """Sets the observed_generation of this V1beta1PipelineRunStatus.

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :param observed_generation: The observed_generation of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: int
        """

        self._observed_generation = observed_generation

    @property
    def pipeline_results(self):
        """Gets the pipeline_results of this V1beta1PipelineRunStatus.  # noqa: E501

        PipelineResults are the list of results written out by the pipeline task's containers  # noqa: E501

        :return: The pipeline_results of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: list[V1beta1PipelineRunResult]
        """
        return self._pipeline_results

    @pipeline_results.setter
    def pipeline_results(self, pipeline_results):
        """Sets the pipeline_results of this V1beta1PipelineRunStatus.

        PipelineResults are the list of results written out by the pipeline task's containers  # noqa: E501

        :param pipeline_results: The pipeline_results of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: list[V1beta1PipelineRunResult]
        """

        self._pipeline_results = pipeline_results

    @property
    def pipeline_spec(self):
        """Gets the pipeline_spec of this V1beta1PipelineRunStatus.  # noqa: E501

        PipelineRunSpec contains the exact spec used to instantiate the run  # noqa: E501

        :return: The pipeline_spec of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: V1beta1PipelineSpec
        """
        return self._pipeline_spec

    @pipeline_spec.setter
    def pipeline_spec(self, pipeline_spec):
        """Sets the pipeline_spec of this V1beta1PipelineRunStatus.

        PipelineRunSpec contains the exact spec used to instantiate the run  # noqa: E501

        :param pipeline_spec: The pipeline_spec of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: V1beta1PipelineSpec
        """

        self._pipeline_spec = pipeline_spec

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1PipelineRunStatus.  # noqa: E501

        StartTime is the time the PipelineRun is actually started.  # noqa: E501

        :return: The start_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1PipelineRunStatus.

        StartTime is the time the PipelineRun is actually started.  # noqa: E501

        :param start_time: The start_time of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    @property
    def task_runs(self):
        """Gets the task_runs of this V1beta1PipelineRunStatus.  # noqa: E501

        map of PipelineRunTaskRunStatus with the taskRun name as the key  # noqa: E501

        :return: The task_runs of this V1beta1PipelineRunStatus.  # noqa: E501
        :rtype: dict(str, V1beta1PipelineRunTaskRunStatus)
        """
        return self._task_runs

    @task_runs.setter
    def task_runs(self, task_runs):
        """Sets the task_runs of this V1beta1PipelineRunStatus.

        map of PipelineRunTaskRunStatus with the taskRun name as the key  # noqa: E501

        :param task_runs: The task_runs of this V1beta1PipelineRunStatus.  # noqa: E501
        :type: dict(str, V1beta1PipelineRunTaskRunStatus)
        """

        self._task_runs = task_runs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1PipelineRunStatus, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineRunStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import tekton
from tekton.models.v1alpha1_resource_param import V1alpha1ResourceParam  # noqa: E501
from tekton.rest import ApiException


class TestV1alpha1ResourceParam(unittest.TestCase):
    """V1alpha1ResourceParam unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1alpha1ResourceParam(self):
        """Test V1alpha1ResourceParam"""
        # FIXME: construct object with mandatory attributes with example values
        # model = tekton.models.v1alpha1_resource_param.V1alpha1ResourceParam()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    KFServing

    Python SDK for KFServing  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kfserving.models.knative_volatile_time import KnativeVolatileTime  # noqa: F401,E501


class KnativeCondition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'last_transition_time': 'KnativeVolatileTime',
        'message': 'str',
        'reason': 'str',
        'severity': 'str',
        'status': 'str',
        'type': 'str'
    }

    attribute_map = {
        'last_transition_time': 'lastTransitionTime',
        'message': 'message',
        'reason': 'reason',
        'severity': 'severity',
        'status': 'status',
        'type': 'type'
    }

    def __init__(self, last_transition_time=None, message=None, reason=None, severity=None, status=None, type=None):  # noqa: E501
        """KnativeCondition - a model defined in Swagger"""  # noqa: E501

        self._last_transition_time = None
        self._message = None
        self._reason = None
        self._severity = None
        self._status = None
        self._type = None
        self.discriminator = None

        if last_transition_time is not None:
            self.last_transition_time = last_transition_time
        if message is not None:
            self.message = message
        if reason is not None:
            self.reason = reason
        if severity is not None:
            self.severity = severity
        self.status = status
        self.type = type

    @property
    def last_transition_time(self):
        """Gets the last_transition_time of this KnativeCondition.  # noqa: E501

        LastTransitionTime is the last time the condition transitioned from one status to another. We use VolatileTime in place of metav1.Time to exclude this from creating equality.Semantic differences (all other things held constant).  # noqa: E501

        :return: The last_transition_time of this KnativeCondition.  # noqa: E501
        :rtype: KnativeVolatileTime
        """
        return self._last_transition_time

    @last_transition_time.setter
    def last_transition_time(self, last_transition_time):
        """Sets the last_transition_time of this KnativeCondition.

        LastTransitionTime is the last time the condition transitioned from one status to another. We use VolatileTime in place of metav1.Time to exclude this from creating equality.Semantic differences (all other things held constant).  # noqa: E501

        :param last_transition_time: The last_transition_time of this KnativeCondition.  # noqa: E501
        :type: KnativeVolatileTime
        """

        self._last_transition_time = last_transition_time

    @property
    def message(self):
        """Gets the message of this KnativeCondition.  # noqa: E501

        A human readable message indicating details about the transition.  # noqa: E501

        :return: The message of this KnativeCondition.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this KnativeCondition.

        A human readable message indicating details about the transition.  # noqa: E501

        :param message: The message of this KnativeCondition.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def reason(self):
        """Gets the reason of this KnativeCondition.  # noqa: E501

        The reason for the condition's last transition.  # noqa: E501

        :return: The reason of this KnativeCondition.  # noqa: E501
        :rtype: str
        """
        return self._reason

    @reason.setter
    def reason(self, reason):
        """Sets the reason of this KnativeCondition.

        The reason for the condition's last transition.  # noqa: E501

        :param reason: The reason of this KnativeCondition.  # noqa: E501
        :type: str
        """

        self._reason = reason

    @property
    def severity(self):
        """Gets the severity of this KnativeCondition.  # noqa: E501

        Severity with which to treat failures of this type of condition. When this is not specified, it defaults to Error.  # noqa: E501

        :return: The severity of this KnativeCondition.  # noqa: E501
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """Sets the severity of this KnativeCondition.

        Severity with which to treat failures of this type of condition. When this is not specified, it defaults to Error.  # noqa: E501

        :param severity: The severity of this KnativeCondition.  # noqa: E501
        :type: str
        """

        self._severity = severity

    @property
    def status(self):
        """Gets the status of this KnativeCondition.  # noqa: E501

        Status of the condition, one of True, False, Unknown.  # noqa: E501

        :return: The status of this KnativeCondition.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this KnativeCondition.

        Status of the condition, one of True, False, Unknown.  # noqa: E501

        :param status: The status of this KnativeCondition.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def type(self):
        """Gets the type of this KnativeCondition.  # noqa: E501

        Type of condition.  # noqa: E501

        :return: The type of this KnativeCondition.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this KnativeCondition.

        Type of condition.  # noqa: E501

        :param type: The type of this KnativeCondition.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(KnativeCondition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, KnativeCondition):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client import V1ContainerStateRunning  # noqa: F401,E501
from kubernetes.client import V1ContainerStateTerminated  # noqa: F401,E501
from kubernetes.client import V1ContainerStateWaiting  # noqa: F401,E501


class V1beta1SidecarState(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'container': 'str',
        'image_id': 'str',
        'name': 'str',
        'running': 'V1ContainerStateRunning',
        'terminated': 'V1ContainerStateTerminated',
        'waiting': 'V1ContainerStateWaiting'
    }

    attribute_map = {
        'container': 'container',
        'image_id': 'imageID',
        'name': 'name',
        'running': 'running',
        'terminated': 'terminated',
        'waiting': 'waiting'
    }

    def __init__(self, container=None, image_id=None, name=None, running=None, terminated=None, waiting=None):  # noqa: E501
        """V1beta1SidecarState - a model defined in Swagger"""  # noqa: E501

        self._container = None
        self._image_id = None
        self._name = None
        self._running = None
        self._terminated = None
        self._waiting = None
        self.discriminator = None

        if container is not None:
            self.container = container
        if image_id is not None:
            self.image_id = image_id
        if name is not None:
            self.name = name
        if running is not None:
            self.running = running
        if terminated is not None:
            self.terminated = terminated
        if waiting is not None:
            self.waiting = waiting

    @property
    def container(self):
        """Gets the container of this V1beta1SidecarState.  # noqa: E501


        :return: The container of this V1beta1SidecarState.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this V1beta1SidecarState.


        :param container: The container of this V1beta1SidecarState.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def image_id(self):
        """Gets the image_id of this V1beta1SidecarState.  # noqa: E501


        :return: The image_id of this V1beta1SidecarState.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this V1beta1SidecarState.


        :param image_id: The image_id of this V1beta1SidecarState.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def name(self):
        """Gets the name of this V1beta1SidecarState.  # noqa: E501


        :return: The name of this V1beta1SidecarState.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1SidecarState.


        :param name: The name of this V1beta1SidecarState.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def running(self):
        """Gets the running of this V1beta1SidecarState.  # noqa: E501

        Details about a running container  # noqa: E501

        :return: The running of this V1beta1SidecarState.  # noqa: E501
        :rtype: V1ContainerStateRunning
        """
        return self._running

    @running.setter
    def running(self, running):
        """Sets the running of this V1beta1SidecarState.

        Details about a running container  # noqa: E501

        :param running: The running of this V1beta1SidecarState.  # noqa: E501
        :type: V1ContainerStateRunning
        """

        self._running = running

    @property
    def terminated(self):
        """Gets the terminated of this V1beta1SidecarState.  # noqa: E501

        Details about a terminated container  # noqa: E501

        :return: The terminated of this V1beta1SidecarState.  # noqa: E501
        :rtype: V1ContainerStateTerminated
        """
        return self._terminated

    @terminated.setter
    def terminated(self, terminated):
        """Sets the terminated of this V1beta1SidecarState.

        Details about a terminated container  # noqa: E501

        :param terminated: The terminated of this V1beta1SidecarState.  # noqa: E501
        :type: V1ContainerStateTerminated
        """

        self._terminated = terminated

    @property
    def waiting(self):
        """Gets the waiting of this V1beta1SidecarState.  # noqa: E501

        Details about a waiting container  # noqa: E501

        :return: The waiting of this V1beta1SidecarState.  # noqa: E501
        :rtype: V1ContainerStateWaiting
        """
        return self._waiting

    @waiting.setter
    def waiting(self, waiting):
        """Sets the waiting of this V1beta1SidecarState.

        Details about a waiting container  # noqa: E501

        :param waiting: The waiting of this V1beta1SidecarState.  # noqa: E501
        :type: V1ContainerStateWaiting
        """

        self._waiting = waiting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1SidecarState, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1SidecarState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from tekton.models.pod_template import PodTemplate  # noqa: F401,E501
from tekton.models.v1_duration import V1Duration  # noqa: F401,E501
from tekton.models.v1beta1_param import V1beta1Param  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_ref import V1beta1PipelineRef  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_resource_binding import V1beta1PipelineResourceBinding  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_run_spec_service_account_name import V1beta1PipelineRunSpecServiceAccountName  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_spec import V1beta1PipelineSpec  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_task_run_spec import V1beta1PipelineTaskRunSpec  # noqa: F401,E501
from tekton.models.v1beta1_workspace_binding import V1beta1WorkspaceBinding  # noqa: F401,E501


class V1beta1PipelineRunSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'params': 'list[V1beta1Param]',
        'pipeline_ref': 'V1beta1PipelineRef',
        'pipeline_spec': 'V1beta1PipelineSpec',
        'pod_template': 'PodTemplate',
        'resources': 'list[V1beta1PipelineResourceBinding]',
        'service_account_name': 'str',
        'service_account_names': 'list[V1beta1PipelineRunSpecServiceAccountName]',
        'status': 'str',
        'task_run_specs': 'list[V1beta1PipelineTaskRunSpec]',
        'timeout': 'V1Duration',
        'workspaces': 'list[V1beta1WorkspaceBinding]'
    }

    attribute_map = {
        'params': 'params',
        'pipeline_ref': 'pipelineRef',
        'pipeline_spec': 'pipelineSpec',
        'pod_template': 'podTemplate',
        'resources': 'resources',
        'service_account_name': 'serviceAccountName',
        'service_account_names': 'serviceAccountNames',
        'status': 'status',
        'task_run_specs': 'taskRunSpecs',
        'timeout': 'timeout',
        'workspaces': 'workspaces'
    }

    def __init__(self, params=None, pipeline_ref=None, pipeline_spec=None, pod_template=None, resources=None, service_account_name=None, service_account_names=None, status=None, task_run_specs=None, timeout=None, workspaces=None):  # noqa: E501
        """V1beta1PipelineRunSpec - a model defined in Swagger"""  # noqa: E501

        self._params = None
        self._pipeline_ref = None
        self._pipeline_spec = None
        self._pod_template = None
        self._resources = None
        self._service_account_name = None
        self._service_account_names = None
        self._status = None
        self._task_run_specs = None
        self._timeout = None
        self._workspaces = None
        self.discriminator = None

        if params is not None:
            self.params = params
        if pipeline_ref is not None:
            self.pipeline_ref = pipeline_ref
        if pipeline_spec is not None:
            self.pipeline_spec = pipeline_spec
        if pod_template is not None:
            self.pod_template = pod_template
        if resources is not None:
            self.resources = resources
        if service_account_name is not None:
            self.service_account_name = service_account_name
        if service_account_names is not None:
            self.service_account_names = service_account_names
        if status is not None:
            self.status = status
        if task_run_specs is not None:
            self.task_run_specs = task_run_specs
        if timeout is not None:
            self.timeout = timeout
        if workspaces is not None:
            self.workspaces = workspaces

    @property
    def params(self):
        """Gets the params of this V1beta1PipelineRunSpec.  # noqa: E501

        Params is a list of parameter names and values.  # noqa: E501

        :return: The params of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: list[V1beta1Param]
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this V1beta1PipelineRunSpec.

        Params is a list of parameter names and values.  # noqa: E501

        :param params: The params of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: list[V1beta1Param]
        """

        self._params = params

    @property
    def pipeline_ref(self):
        """Gets the pipeline_ref of this V1beta1PipelineRunSpec.  # noqa: E501


        :return: The pipeline_ref of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: V1beta1PipelineRef
        """
        return self._pipeline_ref

    @pipeline_ref.setter
    def pipeline_ref(self, pipeline_ref):
        """Sets the pipeline_ref of this V1beta1PipelineRunSpec.


        :param pipeline_ref: The pipeline_ref of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: V1beta1PipelineRef
        """

        self._pipeline_ref = pipeline_ref

    @property
    def pipeline_spec(self):
        """Gets the pipeline_spec of this V1beta1PipelineRunSpec.  # noqa: E501


        :return: The pipeline_spec of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: V1beta1PipelineSpec
        """
        return self._pipeline_spec

    @pipeline_spec.setter
    def pipeline_spec(self, pipeline_spec):
        """Sets the pipeline_spec of this V1beta1PipelineRunSpec.


        :param pipeline_spec: The pipeline_spec of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: V1beta1PipelineSpec
        """

        self._pipeline_spec = pipeline_spec

    @property
    def pod_template(self):
        """Gets the pod_template of this V1beta1PipelineRunSpec.  # noqa: E501

        PodTemplate holds pod specific configuration  # noqa: E501

        :return: The pod_template of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: PodTemplate
        """
        return self._pod_template

    @pod_template.setter
    def pod_template(self, pod_template):
        """Sets the pod_template of this V1beta1PipelineRunSpec.

        PodTemplate holds pod specific configuration  # noqa: E501

        :param pod_template: The pod_template of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: PodTemplate
        """

        self._pod_template = pod_template

    @property
    def resources(self):
        """Gets the resources of this V1beta1PipelineRunSpec.  # noqa: E501

        Resources is a list of bindings specifying which actual instances of PipelineResources to use for the resources the Pipeline has declared it needs.  # noqa: E501

        :return: The resources of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineResourceBinding]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this V1beta1PipelineRunSpec.

        Resources is a list of bindings specifying which actual instances of PipelineResources to use for the resources the Pipeline has declared it needs.  # noqa: E501

        :param resources: The resources of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: list[V1beta1PipelineResourceBinding]
        """

        self._resources = resources

    @property
    def service_account_name(self):
        """Gets the service_account_name of this V1beta1PipelineRunSpec.  # noqa: E501


        :return: The service_account_name of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: str
        """
        return self._service_account_name

    @service_account_name.setter
    def service_account_name(self, service_account_name):
        """Sets the service_account_name of this V1beta1PipelineRunSpec.


        :param service_account_name: The service_account_name of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: str
        """

        self._service_account_name = service_account_name

    @property
    def service_account_names(self):
        """Gets the service_account_names of this V1beta1PipelineRunSpec.  # noqa: E501

        Deprecated: use taskRunSpecs.ServiceAccountName instead  # noqa: E501

        :return: The service_account_names of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineRunSpecServiceAccountName]
        """
        return self._service_account_names

    @service_account_names.setter
    def service_account_names(self, service_account_names):
        """Sets the service_account_names of this V1beta1PipelineRunSpec.

        Deprecated: use taskRunSpecs.ServiceAccountName instead  # noqa: E501

        :param service_account_names: The service_account_names of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: list[V1beta1PipelineRunSpecServiceAccountName]
        """

        self._service_account_names = service_account_names

    @property
    def status(self):
        """Gets the status of this V1beta1PipelineRunSpec.  # noqa: E501

        Used for cancelling a pipelinerun (and maybe more later on)  # noqa: E501

        :return: The status of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this V1beta1PipelineRunSpec.

        Used for cancelling a pipelinerun (and maybe more later on)  # noqa: E501

        :param status: The status of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def task_run_specs(self):
        """Gets the task_run_specs of this V1beta1PipelineRunSpec.  # noqa: E501

        TaskRunSpecs holds a set of runtime specs  # noqa: E501

        :return: The task_run_specs of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineTaskRunSpec]
        """
        return self._task_run_specs

    @task_run_specs.setter
    def task_run_specs(self, task_run_specs):
        """Sets the task_run_specs of this V1beta1PipelineRunSpec.

        TaskRunSpecs holds a set of runtime specs  # noqa: E501

        :param task_run_specs: The task_run_specs of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: list[V1beta1PipelineTaskRunSpec]
        """

        self._task_run_specs = task_run_specs

    @property
    def timeout(self):
        """Gets the timeout of this V1beta1PipelineRunSpec.  # noqa: E501

        Time after which the Pipeline times out. Defaults to never. Refer to Go's ParseDuration documentation for expected format: https://golang.org/pkg/time/#ParseDuration  # noqa: E501

        :return: The timeout of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: V1Duration
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this V1beta1PipelineRunSpec.

        Time after which the Pipeline times out. Defaults to never. Refer to Go's ParseDuration documentation for expected format: https://golang.org/pkg/time/#ParseDuration  # noqa: E501

        :param timeout: The timeout of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: V1Duration
        """

        self._timeout = timeout

    @property
    def workspaces(self):
        """Gets the workspaces of this V1beta1PipelineRunSpec.  # noqa: E501

        Workspaces holds a set of workspace bindings that must match names with those declared in the pipeline.  # noqa: E501

        :return: The workspaces of this V1beta1PipelineRunSpec.  # noqa: E501
        :rtype: list[V1beta1WorkspaceBinding]
        """
        return self._workspaces

    @workspaces.setter
    def workspaces(self, workspaces):
        """Sets the workspaces of this V1beta1PipelineRunSpec.

        Workspaces holds a set of workspace bindings that must match names with those declared in the pipeline.  # noqa: E501

        :param workspaces: The workspaces of this V1beta1PipelineRunSpec.  # noqa: E501
        :type: list[V1beta1WorkspaceBinding]
        """

        self._workspaces = workspaces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1PipelineRunSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineRunSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from tekton.models.v1_time import V1Time  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_run_result import V1beta1PipelineRunResult  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_run_task_run_status import V1beta1PipelineRunTaskRunStatus  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_spec import V1beta1PipelineSpec  # noqa: F401,E501


class V1beta1PipelineRunStatusFields(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'completion_time': 'V1Time',
        'pipeline_results': 'list[V1beta1PipelineRunResult]',
        'pipeline_spec': 'V1beta1PipelineSpec',
        'start_time': 'V1Time',
        'task_runs': 'dict(str, V1beta1PipelineRunTaskRunStatus)'
    }

    attribute_map = {
        'completion_time': 'completionTime',
        'pipeline_results': 'pipelineResults',
        'pipeline_spec': 'pipelineSpec',
        'start_time': 'startTime',
        'task_runs': 'taskRuns'
    }

    def __init__(self, completion_time=None, pipeline_results=None, pipeline_spec=None, start_time=None, task_runs=None):  # noqa: E501
        """V1beta1PipelineRunStatusFields - a model defined in Swagger"""  # noqa: E501

        self._completion_time = None
        self._pipeline_results = None
        self._pipeline_spec = None
        self._start_time = None
        self._task_runs = None
        self.discriminator = None

        if completion_time is not None:
            self.completion_time = completion_time
        if pipeline_results is not None:
            self.pipeline_results = pipeline_results
        if pipeline_spec is not None:
            self.pipeline_spec = pipeline_spec
        if start_time is not None:
            self.start_time = start_time
        if task_runs is not None:
            self.task_runs = task_runs

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1PipelineRunStatusFields.  # noqa: E501

        CompletionTime is the time the PipelineRun completed.  # noqa: E501

        :return: The completion_time of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1PipelineRunStatusFields.

        CompletionTime is the time the PipelineRun completed.  # noqa: E501

        :param completion_time: The completion_time of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def pipeline_results(self):
        """Gets the pipeline_results of this V1beta1PipelineRunStatusFields.  # noqa: E501

        PipelineResults are the list of results written out by the pipeline task's containers  # noqa: E501

        :return: The pipeline_results of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :rtype: list[V1beta1PipelineRunResult]
        """
        return self._pipeline_results

    @pipeline_results.setter
    def pipeline_results(self, pipeline_results):
        """Sets the pipeline_results of this V1beta1PipelineRunStatusFields.

        PipelineResults are the list of results written out by the pipeline task's containers  # noqa: E501

        :param pipeline_results: The pipeline_results of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :type: list[V1beta1PipelineRunResult]
        """

        self._pipeline_results = pipeline_results

    @property
    def pipeline_spec(self):
        """Gets the pipeline_spec of this V1beta1PipelineRunStatusFields.  # noqa: E501

        PipelineRunSpec contains the exact spec used to instantiate the run  # noqa: E501

        :return: The pipeline_spec of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :rtype: V1beta1PipelineSpec
        """
        return self._pipeline_spec

    @pipeline_spec.setter
    def pipeline_spec(self, pipeline_spec):
        """Sets the pipeline_spec of this V1beta1PipelineRunStatusFields.

        PipelineRunSpec contains the exact spec used to instantiate the run  # noqa: E501

        :param pipeline_spec: The pipeline_spec of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :type: V1beta1PipelineSpec
        """

        self._pipeline_spec = pipeline_spec

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1PipelineRunStatusFields.  # noqa: E501

        StartTime is the time the PipelineRun is actually started.  # noqa: E501

        :return: The start_time of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1PipelineRunStatusFields.

        StartTime is the time the PipelineRun is actually started.  # noqa: E501

        :param start_time: The start_time of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    @property
    def task_runs(self):
        """Gets the task_runs of this V1beta1PipelineRunStatusFields.  # noqa: E501

        map of PipelineRunTaskRunStatus with the taskRun name as the key  # noqa: E501

        :return: The task_runs of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :rtype: dict(str, V1beta1PipelineRunTaskRunStatus)
        """
        return self._task_runs

    @task_runs.setter
    def task_runs(self, task_runs):
        """Sets the task_runs of this V1beta1PipelineRunStatusFields.

        map of PipelineRunTaskRunStatus with the taskRun name as the key  # noqa: E501

        :param task_runs: The task_runs of this V1beta1PipelineRunStatusFields.  # noqa: E501
        :type: dict(str, V1beta1PipelineRunTaskRunStatus)
        """

        self._task_runs = task_runs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1PipelineRunStatusFields, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineRunStatusFields):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from tekton.models.v1alpha1_pipeline_resource_spec import V1alpha1PipelineResourceSpec  # noqa: F401,E501
from tekton.models.v1beta1_pipeline_resource_ref import V1beta1PipelineResourceRef  # noqa: F401,E501


class V1beta1TaskResourceBinding(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'paths': 'list[str]',
        'resource_ref': 'V1beta1PipelineResourceRef',
        'resource_spec': 'V1alpha1PipelineResourceSpec'
    }

    attribute_map = {
        'name': 'name',
        'paths': 'paths',
        'resource_ref': 'resourceRef',
        'resource_spec': 'resourceSpec'
    }

    def __init__(self, name=None, paths=None, resource_ref=None, resource_spec=None):  # noqa: E501
        """V1beta1TaskResourceBinding - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._paths = None
        self._resource_ref = None
        self._resource_spec = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if paths is not None:
            self.paths = paths
        if resource_ref is not None:
            self.resource_ref = resource_ref
        if resource_spec is not None:
            self.resource_spec = resource_spec

    @property
    def name(self):
        """Gets the name of this V1beta1TaskResourceBinding.  # noqa: E501

        Name is the name of the PipelineResource in the Pipeline's declaration  # noqa: E501

        :return: The name of this V1beta1TaskResourceBinding.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1TaskResourceBinding.

        Name is the name of the PipelineResource in the Pipeline's declaration  # noqa: E501

        :param name: The name of this V1beta1TaskResourceBinding.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def paths(self):
        """Gets the paths of this V1beta1TaskResourceBinding.  # noqa: E501

        Paths will probably be removed in #1284, and then PipelineResourceBinding can be used instead. The optional Path field corresponds to a path on disk at which the Resource can be found (used when providing the resource via mounted volume, overriding the default logic to fetch the Resource).  # noqa: E501

        :return: The paths of this V1beta1TaskResourceBinding.  # noqa: E501
        :rtype: list[str]
        """
        return self._paths

    @paths.setter
    def paths(self, paths):
        """Sets the paths of this V1beta1TaskResourceBinding.

        Paths will probably be removed in #1284, and then PipelineResourceBinding can be used instead. The optional Path field corresponds to a path on disk at which the Resource can be found (used when providing the resource via mounted volume, overriding the default logic to fetch the Resource).  # noqa: E501

        :param paths: The paths of this V1beta1TaskResourceBinding.  # noqa: E501
        :type: list[str]
        """

        self._paths = paths

    @property
    def resource_ref(self):
        """Gets the resource_ref of this V1beta1TaskResourceBinding.  # noqa: E501

        ResourceRef is a reference to the instance of the actual PipelineResource that should be used  # noqa: E501

        :return: The resource_ref of this V1beta1TaskResourceBinding.  # noqa: E501
        :rtype: V1beta1PipelineResourceRef
        """
        return self._resource_ref

    @resource_ref.setter
    def resource_ref(self, resource_ref):
        """Sets the resource_ref of this V1beta1TaskResourceBinding.

        ResourceRef is a reference to the instance of the actual PipelineResource that should be used  # noqa: E501

        :param resource_ref: The resource_ref of this V1beta1TaskResourceBinding.  # noqa: E501
        :type: V1beta1PipelineResourceRef
        """

        self._resource_ref = resource_ref

    @property
    def resource_spec(self):
        """Gets the resource_spec of this V1beta1TaskResourceBinding.  # noqa: E501

        ResourceSpec is specification of a resource that should be created and consumed by the task  # noqa: E501

        :return: The resource_spec of this V1beta1TaskResourceBinding.  # noqa: E501
        :rtype: V1alpha1PipelineResourceSpec
        """
        return self._resource_spec

    @resource_spec.setter
    def resource_spec(self, resource_spec):
        """Sets the resource_spec of this V1beta1TaskResourceBinding.

        ResourceSpec is specification of a resource that should be created and consumed by the task  # noqa: E501

        :param resource_spec: The resource_spec of this V1beta1TaskResourceBinding.  # noqa: E501
        :type: V1alpha1PipelineResourceSpec
        """

        self._resource_spec = resource_spec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1TaskResourceBinding, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TaskResourceBinding):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import tekton
from tekton.models.v1beta1_condition_check import V1beta1ConditionCheck  # noqa: E501
from tekton.rest import ApiException


class TestV1beta1ConditionCheck(unittest.TestCase):
    """V1beta1ConditionCheck unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1beta1ConditionCheck(self):
        """Test V1beta1ConditionCheck"""
        # FIXME: construct object with mandatory attributes with example values
        # model = tekton.models.v1beta1_condition_check.V1beta1ConditionCheck()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from tekton.models.v1_time import V1Time  # noqa: F401,E501


class V1beta1CloudEventDeliveryState(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition': 'str',
        'message': 'str',
        'retry_count': 'int',
        'sent_at': 'V1Time'
    }

    attribute_map = {
        'condition': 'condition',
        'message': 'message',
        'retry_count': 'retryCount',
        'sent_at': 'sentAt'
    }

    def __init__(self, condition=None, message=None, retry_count=None, sent_at=None):  # noqa: E501
        """V1beta1CloudEventDeliveryState - a model defined in Swagger"""  # noqa: E501

        self._condition = None
        self._message = None
        self._retry_count = None
        self._sent_at = None
        self.discriminator = None

        if condition is not None:
            self.condition = condition
        self.message = message
        self.retry_count = retry_count
        if sent_at is not None:
            self.sent_at = sent_at

    @property
    def condition(self):
        """Gets the condition of this V1beta1CloudEventDeliveryState.  # noqa: E501

        Current status  # noqa: E501

        :return: The condition of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """Sets the condition of this V1beta1CloudEventDeliveryState.

        Current status  # noqa: E501

        :param condition: The condition of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :type: str
        """

        self._condition = condition

    @property
    def message(self):
        """Gets the message of this V1beta1CloudEventDeliveryState.  # noqa: E501

        Error is the text of error (if any)  # noqa: E501

        :return: The message of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this V1beta1CloudEventDeliveryState.

        Error is the text of error (if any)  # noqa: E501

        :param message: The message of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")  # noqa: E501

        self._message = message

    @property
    def retry_count(self):
        """Gets the retry_count of this V1beta1CloudEventDeliveryState.  # noqa: E501

        RetryCount is the number of attempts of sending the cloud event  # noqa: E501

        :return: The retry_count of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :rtype: int
        """
        return self._retry_count

    @retry_count.setter
    def retry_count(self, retry_count):
        """Sets the retry_count of this V1beta1CloudEventDeliveryState.

        RetryCount is the number of attempts of sending the cloud event  # noqa: E501

        :param retry_count: The retry_count of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :type: int
        """
        if retry_count is None:
            raise ValueError("Invalid value for `retry_count`, must not be `None`")  # noqa: E501

        self._retry_count = retry_count

    @property
    def sent_at(self):
        """Gets the sent_at of this V1beta1CloudEventDeliveryState.  # noqa: E501

        SentAt is the time at which the last attempt to send the event was made  # noqa: E501

        :return: The sent_at of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :rtype: V1Time
        """
        return self._sent_at

    @sent_at.setter
    def sent_at(self, sent_at):
        """Sets the sent_at of this V1beta1CloudEventDeliveryState.

        SentAt is the time at which the last attempt to send the event was made  # noqa: E501

        :param sent_at: The sent_at of this V1beta1CloudEventDeliveryState.  # noqa: E501
        :type: V1Time
        """

        self._sent_at = sent_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1CloudEventDeliveryState, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1CloudEventDeliveryState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client import V1ObjectMeta  # noqa: F401,E501
from tekton.models.v1alpha1_pipeline_resource_spec import V1alpha1PipelineResourceSpec  # noqa: F401,E501
from tekton.models.v1alpha1_pipeline_resource_status import V1alpha1PipelineResourceStatus  # noqa: F401,E501


class V1alpha1PipelineResource(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'api_version': 'str',
        'kind': 'str',
        'metadata': 'V1ObjectMeta',
        'spec': 'V1alpha1PipelineResourceSpec',
        'status': 'V1alpha1PipelineResourceStatus'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'kind': 'kind',
        'metadata': 'metadata',
        'spec': 'spec',
        'status': 'status'
    }

    def __init__(self, api_version=None, kind=None, metadata=None, spec=None, status=None):  # noqa: E501
        """V1alpha1PipelineResource - a model defined in Swagger"""  # noqa: E501

        self._api_version = None
        self._kind = None
        self._metadata = None
        self._spec = None
        self._status = None
        self.discriminator = None

        if api_version is not None:
            self.api_version = api_version
        if kind is not None:
            self.kind = kind
        if metadata is not None:
            self.metadata = metadata
        if spec is not None:
            self.spec = spec
        if status is not None:
            self.status = status

    @property
    def api_version(self):
        """Gets the api_version of this V1alpha1PipelineResource.  # noqa: E501

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources  # noqa: E501

        :return: The api_version of this V1alpha1PipelineResource.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this V1alpha1PipelineResource.

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources  # noqa: E501

        :param api_version: The api_version of this V1alpha1PipelineResource.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def kind(self):
        """Gets the kind of this V1alpha1PipelineResource.  # noqa: E501

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds  # noqa: E501

        :return: The kind of this V1alpha1PipelineResource.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1alpha1PipelineResource.

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds  # noqa: E501

        :param kind: The kind of this V1alpha1PipelineResource.  # noqa: E501
        :type: str
        """

        self._kind = kind

    @property
    def metadata(self):
        """Gets the metadata of this V1alpha1PipelineResource.  # noqa: E501


        :return: The metadata of this V1alpha1PipelineResource.  # noqa: E501
        :rtype: V1ObjectMeta
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this V1alpha1PipelineResource.


        :param metadata: The metadata of this V1alpha1PipelineResource.  # noqa: E501
        :type: V1ObjectMeta
        """

        self._metadata = metadata

    @property
    def spec(self):
        """Gets the spec of this V1alpha1PipelineResource.  # noqa: E501

        Spec holds the desired state of the PipelineResource from the client  # noqa: E501

        :return: The spec of this V1alpha1PipelineResource.  # noqa: E501
        :rtype: V1alpha1PipelineResourceSpec
        """
        return self._spec

    @spec.setter
    def spec(self, spec):
        """Sets the spec of this V1alpha1PipelineResource.

        Spec holds the desired state of the PipelineResource from the client  # noqa: E501

        :param spec: The spec of this V1alpha1PipelineResource.  # noqa: E501
        :type: V1alpha1PipelineResourceSpec
        """

        self._spec = spec

    @property
    def status(self):
        """Gets the status of this V1alpha1PipelineResource.  # noqa: E501

        Status is deprecated. It usually is used to communicate the observed state of the PipelineResource from the controller, but was unused as there is no controller for PipelineResource.  # noqa: E501

        :return: The status of this V1alpha1PipelineResource.  # noqa: E501
        :rtype: V1alpha1PipelineResourceStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this V1alpha1PipelineResource.

        Status is deprecated. It usually is used to communicate the observed state of the PipelineResource from the controller, but was unused as there is no controller for PipelineResource.  # noqa: E501

        :param status: The status of this V1alpha1PipelineResource.  # noqa: E501
        :type: V1alpha1PipelineResourceStatus
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1alpha1PipelineResource, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha1PipelineResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other




import time
from kubernetes import client, config

from ..constants import constants
from ..utils import utils


class TektonClient(object):

    def __init__(self, config_file=None, context=None,
                 client_configuration=None, persist_config=True):
        """
        Tekton client constructor
        :param config_file: kubeconfig file, defaults to ~/.kube/config
        :param context: kubernetes context
        :param client_configuration: kubernetes configuration object
        :param persist_config:
        """
        if config_file or not utils.is_running_in_k8s():
            config.load_kube_config(
                config_file=config_file,
                context=context,
                client_configuration=client_configuration,
                persist_config=persist_config)
        else:
            config.load_incluster_config()
        self.core_api = client.CoreV1Api()
        self.app_api = client.AppsV1Api()
        self.api_instance = client.CustomObjectsApi()

    def create(self, tekton, plural=None, namespace=None):
        """
        Create the Tekton objects
        :param tekton: Tekton objects
        :param plural: the custom object's plural name. 
        :param namespace: defaults to current or default namespace
        :return: created Tekton objects
        """

        if namespace is None:
            namespace = utils.get_tekton_namespace(tekton)

        if plural is None:
            plural = utils.get_tekton_plural(tekton)

        try:
            outputs = self.api_instance.create_namespaced_custom_object(
                constants.TEKTON_GROUP,
                constants.TEKTON_VERSION,
                namespace,
                plural,
                tekton)
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->create_namespaced_custom_object:\
                 %s\n" % e)

        return outputs

    def get(self, name, plural, namespace=None):
        """
        Get the Tekton objects
        :param name: existing Tekton objects
        :param plural: the custom object's plural name. 
        :param namespace: defaults to current or default namespace
        :return: Tekton objects
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        try:
            return self.api_instance.get_namespaced_custom_object(
                constants.TEKTON_GROUP,
                constants.TEKTON_VERSION,
                namespace,
                plural,
                name)
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->get_namespaced_custom_object:\
                %s\n" % e)


    def delete(self, name, plural, namespace=None):
        """
        Delete the Tekton objects
        :param name: Tekton object's name
        :param plural: the custom object's plural name. 
        :param namespace: defaults to current or default namespace
        :return:
        """
        if namespace is None:
            namespace = utils.get_default_target_namespace()

        try:
            return self.api_instance.delete_namespaced_custom_object(
                constants.TEKTON_GROUP,
                constants.TEKTON_VERSION,
                namespace,
                plural,
                name,
                client.V1DeleteOptions())
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->delete_namespaced_custom_object:\
                 %s\n" % e)



# coding: utf-8

"""
    Tekton

    Python SDK for Tekton Pipeline  # noqa: E501

    OpenAPI spec version: v0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client import V1Volume  # noqa: F401,E501
from tekton.models.v1beta1_step import V1beta1Step  # noqa: F401,E501


class V1beta1InternalTaskModifier(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'steps_to_append': 'list[V1beta1Step]',
        'steps_to_prepend': 'list[V1beta1Step]',
        'volumes': 'list[V1Volume]'
    }

    attribute_map = {
        'steps_to_append': 'StepsToAppend',
        'steps_to_prepend': 'StepsToPrepend',
        'volumes': 'Volumes'
    }

    def __init__(self, steps_to_append=None, steps_to_prepend=None, volumes=None):  # noqa: E501
        """V1beta1InternalTaskModifier - a model defined in Swagger"""  # noqa: E501

        self._steps_to_append = None
        self._steps_to_prepend = None
        self._volumes = None
        self.discriminator = None

        self.steps_to_append = steps_to_append
        self.steps_to_prepend = steps_to_prepend
        self.volumes = volumes

    @property
    def steps_to_append(self):
        """Gets the steps_to_append of this V1beta1InternalTaskModifier.  # noqa: E501


        :return: The steps_to_append of this V1beta1InternalTaskModifier.  # noqa: E501
        :rtype: list[V1beta1Step]
        """
        return self._steps_to_append

    @steps_to_append.setter
    def steps_to_append(self, steps_to_append):
        """Sets the steps_to_append of this V1beta1InternalTaskModifier.


        :param steps_to_append: The steps_to_append of this V1beta1InternalTaskModifier.  # noqa: E501
        :type: list[V1beta1Step]
        """
        if steps_to_append is None:
            raise ValueError("Invalid value for `steps_to_append`, must not be `None`")  # noqa: E501

        self._steps_to_append = steps_to_append

    @property
    def steps_to_prepend(self):
        """Gets the steps_to_prepend of this V1beta1InternalTaskModifier.  # noqa: E501


        :return: The steps_to_prepend of this V1beta1InternalTaskModifier.  # noqa: E501
        :rtype: list[V1beta1Step]
        """
        return self._steps_to_prepend

    @steps_to_prepend.setter
    def steps_to_prepend(self, steps_to_prepend):
        """Sets the steps_to_prepend of this V1beta1InternalTaskModifier.


        :param steps_to_prepend: The steps_to_prepend of this V1beta1InternalTaskModifier.  # noqa: E501
        :type: list[V1beta1Step]
        """
        if steps_to_prepend is None:
            raise ValueError("Invalid value for `steps_to_prepend`, must not be `None`")  # noqa: E501

        self._steps_to_prepend = steps_to_prepend

    @property
    def volumes(self):
        """Gets the volumes of this V1beta1InternalTaskModifier.  # noqa: E501


        :return: The volumes of this V1beta1InternalTaskModifier.  # noqa: E501
        :rtype: list[V1Volume]
        """
        return self._volumes

    @volumes.setter
    def volumes(self, volumes):
        """Sets the volumes of this V1beta1InternalTaskModifier.


        :param volumes: The volumes of this V1beta1InternalTaskModifier.  # noqa: E501
        :type: list[V1Volume]
        """
        if volumes is None:
            raise ValueError("Invalid value for `volumes`, must not be `None`")  # noqa: E501

        self._volumes = volumes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1beta1InternalTaskModifier, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1InternalTaskModifier):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
